# labb Icons

Collection of icons packs ready to use in your Django project. It is standalone and can be used independently of the [labb UI components](https://labb.io/docs/ui).

## Installation

```bash
pip install labbicons
# or both labb and labbicons
pip install labbui[icons]
```

## Usage

```html
<c-lbi.rmx.heart w="24" h="24" class="text-red-500" />
```

## CLI Commands

```bash
labb icons search "arrow"
labb icons info rmx.arrow-down
labb icons packs
```

For complete documentation, see the [labb Icons documentation](https://labb.io/docs/icons).
